#include <stdio.h>
#include <stdlib.h>
#include "main.h"
#include "Graphics.h"
#include "System.h"
#include "math.h"
#include "formats/TGA.h"

#define SCREEN_WIDTH    640
#define SCREEN_HEIGHT   480

int main(int argc, char* argv[])
{
    // init the window
    gfx.init("Bump", SCREEN_WIDTH, SCREEN_HEIGHT);
    gfx.init2D();
    gfx.clearScreen(Color(0, 0, 0, SDL_ALPHA_OPAQUE));
    int width, height;

    Color* background = tga.load("background.tga", &width, &height);
    Color* lightImage = tga.load("light.tga", &width, &height);

    int lightPosX, lightPosY;
    float angle = 0.0f;

    while (sys.isQuitRequested() == false)
    {
        // move the light
        lightPosX = 160 * sin(angle);
        lightPosY = 120 * sin(2.0f * angle);
        angle += 0.02f;

        // draw the image
        for (int y = 0; y < SCREEN_HEIGHT; ++y)
            for (int x = 0; x < SCREEN_WIDTH; ++x)
            {
                // compute the light intensity
                int light = 0;
                int lightX = x + lightPosX;
                int lightY = y + lightPosY;

                if (lightX >= 0 && lightX < SCREEN_WIDTH &&
                    lightY >= 0 && lightY < SCREEN_HEIGHT)
                {
                    light = lightImage[lightY * SCREEN_WIDTH + lightX].r;
                }

                // get the background color
                Color col = background[y * SCREEN_WIDTH + x];

                // modulate the color by the light intensity
                col.r = col.r * light / 255;
                col.g = col.g * light / 255;
                col.b = col.b * light / 255;

                gfx.setPixel(x, y, col);
            }

        gfx.render();
        sys.processEvents();
        sys.wait(16);
    }

    gfx.quit();
    delete[] lightImage;
    delete[] background;

    return EXIT_SUCCESS;
}
